@@ -86,7 +86,7 @@
 #define KRUNNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KRUNNER_NO_DEPRECATED
-#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
+#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
 #endif
 #ifdef KRUNNER_NO_DEPRECATED_WARNINGS
 #  define KRUNNER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KRUNNER_DEPRECATED_WARNINGS_SINCE KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x55500
+#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x55800
 #  endif
 #endif
 
@@ -169,6 +169,18 @@
 #else
 #  define KRUNNER_DEPRECATED_VERSION_5_85(text)
 #endif
+
+#if KRUNNER_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KRUNNER_DEPRECATED_VERSION_5_86(text) KRUNNER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KRUNNER_DEPRECATED_VERSION_5_86(text)
+#endif
+
+#if KRUNNER_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KRUNNER_DEPRECATED_VERSION_5_88(text) KRUNNER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KRUNNER_DEPRECATED_VERSION_5_88(text)
+#endif
 #define KRUNNER_DEPRECATED_VERSION_5(minor, text)      KRUNNER_DEPRECATED_VERSION_5_##minor(text)
 #define KRUNNER_DEPRECATED_VERSION(major, minor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KRUNNER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -234,7 +246,7 @@
 #define KRUNNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KRUNNER_NO_DEPRECATED
-#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
+#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
 #endif
 #ifdef KRUNNER_NO_DEPRECATED_WARNINGS
 #  define KRUNNER_DEPRECATED_WARNINGS_SINCE 0
@@ -244,7 +256,7 @@
 #  ifdef KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KRUNNER_DEPRECATED_WARNINGS_SINCE KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x55500
+#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x55800
 #  endif
 #endif
 
@@ -317,6 +329,18 @@
 #else
 #  define KRUNNER_DEPRECATED_VERSION_5_85(text)
 #endif
+
+#if KRUNNER_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KRUNNER_DEPRECATED_VERSION_5_86(text) KRUNNER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KRUNNER_DEPRECATED_VERSION_5_86(text)
+#endif
+
+#if KRUNNER_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KRUNNER_DEPRECATED_VERSION_5_88(text) KRUNNER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KRUNNER_DEPRECATED_VERSION_5_88(text)
+#endif
 #define KRUNNER_DEPRECATED_VERSION_5(minor, text)      KRUNNER_DEPRECATED_VERSION_5_##minor(text)
 #define KRUNNER_DEPRECATED_VERSION(major, minor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KRUNNER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
